from .ChampionApiV3 import ChampionApiV3
from .ChampionMasteryApiV4 import ChampionMasteryApiV4
from .ClashApiV1 import ClashApiV1
from .DataDragonApi import DataDragonApi
from .LeagueApiV4 import LeagueApiV4
from .LolStatusApiV3 import LolStatusApiV3
from .MatchApiV4 import MatchApiV4
from .SpectatorApiV4 import SpectatorApiV4
from .SummonerApiV4 import SummonerApiV4
from .ThirdPartyCodeApiV4 import ThirdPartyCodeApiV4
from .MatchApiV5 import MatchApiV5
